#[repr(i32)]pub enum cutensorAlgo_t {
CUTENSOR_ALGO_DEFAULT_PATIENT = -6,
CUTENSOR_ALGO_GETT = -4,
CUTENSOR_ALGO_TGETT = -3,
CUTENSOR_ALGO_TTGT = -2,
CUTENSOR_ALGO_DEFAULT = -1,
}Expand description
Allows users to specify the algorithm to be used for performing the desired tensor operation.
Variants
CUTENSOR_ALGO_DEFAULT_PATIENT = -6
More time-consuming than CUTENSOR_DEFAULT, but typically provides a more accurate kernel selection.
CUTENSOR_ALGO_GETT = -4
Choose the GETT algorithm (only applicable to contractions).
CUTENSOR_ALGO_TGETT = -3
Transpose (A or B) + GETT (only applicable to contractions).
CUTENSOR_ALGO_TTGT = -2
Transpose-Transpose-GEMM-Transpose (requires additional memory) (only applicable to contractions).
CUTENSOR_ALGO_DEFAULT = -1
A performance model chooses the appropriate algorithm and kernel.