cutensorAutotuneMode_t

Enum cutensorAutotuneMode_t 

#[repr(u32)]
pub enum cutensorAutotuneMode_t { CUTENSOR_AUTOTUNE_MODE_NONE = 0, CUTENSOR_AUTOTUNE_MODE_INCREMENTAL = 1, }
This enum determines the mode w.r.t. cuTENSOR’s auto-tuning capability.

Variants



CUTENSOR_AUTOTUNE_MODE_NONE = 0

Indicates no autotuning (default); in this case the cache will help to reduce the plan-creation overhead. In the case of a cachehit: the cached plan will be reused, otherwise the plancache will be neglected.



CUTENSOR_AUTOTUNE_MODE_INCREMENTAL = 1

Indicates an incremental autotuning (i.e., each invocation of corresponding cutensorCreatePlan() will create a plan based on a different algorithm/kernel; the maximum number of kernels that will be tested is defined by the cutensorPlanPreferenceAttribute_t::CUTENSOR_PLAN_PREFERENCE_INCREMENTAL_COUNT of cutensorPlanPreferenceAttribute_t). WARNING: If this autotuning mode is selected, then we cannot guarantee bit-wise identical results (since different algorithms could be executed).