#[repr(i32)]pub enum cutensorMgHostDevice_t {
CUTENSOR_MG_DEVICE_HOST = -1,
CUTENSOR_MG_DEVICE_HOST_PINNED = -2,
}Expand description
Enumerated device codes for host-side tensors.
Variants
CUTENSOR_MG_DEVICE_HOST = -1
The memory is located on the host in regular memory.
CUTENSOR_MG_DEVICE_HOST_PINNED = -2
The memory is located on the host in pinned memory.