#[repr(u32)]pub enum cutensorOperationDescriptorAttribute_t {
CUTENSOR_OPERATION_DESCRIPTOR_TAG = 0,
CUTENSOR_OPERATION_DESCRIPTOR_SCALAR_TYPE = 1,
CUTENSOR_OPERATION_DESCRIPTOR_FLOPS = 2,
CUTENSOR_OPERATION_DESCRIPTOR_MOVED_BYTES = 3,
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_LEFT = 4,
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_RIGHT = 5,
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_VALUE = 6,
}Expand description
This enum lists all attributes of a cutensorOperationDescriptor_t that can be modified (see cutensorOperationDescriptorSetAttribute and cutensorOperationDescriptorGetAttribute).
Variants
CUTENSOR_OPERATION_DESCRIPTOR_TAG = 0
int32_t: enables users to distinguish two identical problems with respect to the sw-managed plan-cache. (default value: 0).
CUTENSOR_OPERATION_DESCRIPTOR_SCALAR_TYPE = 1
cudaDataType_t: data type of the scaling factors.
CUTENSOR_OPERATION_DESCRIPTOR_FLOPS = 2
float: number of floating-point operations necessary to perform this operation (assuming all scalar are not equal to zero, unless otherwise specified).
CUTENSOR_OPERATION_DESCRIPTOR_MOVED_BYTES = 3
float: minimal number of bytes transferred from/to global-memory (assuming all scalar are not equal to zero, unless otherwise specified).
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_LEFT = 4
uint32_t[] (of size descOut->numModes): Each entry i holds the number of padded values that should be padded to the left of the ith dimension.
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_RIGHT = 5
uint32_t[] (of size descOut->numModes): Each entry i holds the number of padded values that should be padded to the right of the ith dimension.
CUTENSOR_OPERATION_DESCRIPTOR_PADDING_VALUE = 6
host-side pointer to element of the same type as the output tensor: Constant padding value.