cutensorPlanPreferenceAttribute_t

Enum cutensorPlanPreferenceAttribute_t 

#[repr(u32)]
pub enum cutensorPlanPreferenceAttribute_t { CUTENSOR_PLAN_PREFERENCE_AUTOTUNE_MODE = 0, CUTENSOR_PLAN_PREFERENCE_CACHE_MODE = 1, CUTENSOR_PLAN_PREFERENCE_INCREMENTAL_COUNT = 2, CUTENSOR_PLAN_PREFERENCE_ALGO = 3, CUTENSOR_PLAN_PREFERENCE_KERNEL_RANK = 4, CUTENSOR_PLAN_PREFERENCE_JIT = 5, CUTENSOR_PLAN_PREFERENCE_GPU_ARCH = 6, }
This enum lists all attributes of a cutensorPlanPreference_t object that can be modified.

Variants



CUTENSOR_PLAN_PREFERENCE_AUTOTUNE_MODE = 0

cutensorAutotuneMode_t: Determines if recurrent executions of the plan (e.g., via cutensorContract, cutensorPermute) should autotune (i.e., try different kernels); see section “Plan Cache” for details.



CUTENSOR_PLAN_PREFERENCE_CACHE_MODE = 1

cutensorCacheMode_t: Determines if the corresponding algorithm/kernel for this plan should be cached and it gives fine control over what is considered a cachehit.



CUTENSOR_PLAN_PREFERENCE_INCREMENTAL_COUNT = 2



CUTENSOR_PLAN_PREFERENCE_ALGO = 3

cutensorAlgo_t: Fixes a certain cutensorAlgo_t.



CUTENSOR_PLAN_PREFERENCE_KERNEL_RANK = 4

int32_t: Fixes a kernel (a sub variant of an algo; e.g., kernel_rank==1 while algo == cutensorAlgo_t::CUTENSOR_ALGO_TGETT would select the second-best GETT kernel/variant according to cuTENSOR’s performance model; kernel_rank==2 would select the third-best).



CUTENSOR_PLAN_PREFERENCE_JIT = 5

cutensorJitMode_t: determines if just-in-time compilation is enabled or disabled (default: cutensorJitMode_t::CUTENSOR_JIT_MODE_NONE).



CUTENSOR_PLAN_PREFERENCE_GPU_ARCH = 6

int32_t: Plan for a specific GPU architecture and not one associated with the context. Value should encode SM version via 10 * SM.major + SM.minor. Currently only SM versions 80, 90 and 100 are supported.