#[repr(u32)]pub enum cutensorStatus_t {
Show 15 variants
CUTENSOR_STATUS_SUCCESS = 0,
CUTENSOR_STATUS_NOT_INITIALIZED = 1,
CUTENSOR_STATUS_ALLOC_FAILED = 3,
CUTENSOR_STATUS_INVALID_VALUE = 7,
CUTENSOR_STATUS_ARCH_MISMATCH = 8,
CUTENSOR_STATUS_MAPPING_ERROR = 11,
CUTENSOR_STATUS_EXECUTION_FAILED = 13,
CUTENSOR_STATUS_INTERNAL_ERROR = 14,
CUTENSOR_STATUS_NOT_SUPPORTED = 15,
CUTENSOR_STATUS_LICENSE_ERROR = 16,
CUTENSOR_STATUS_CUBLAS_ERROR = 17,
CUTENSOR_STATUS_CUDA_ERROR = 18,
CUTENSOR_STATUS_INSUFFICIENT_WORKSPACE = 19,
CUTENSOR_STATUS_INSUFFICIENT_DRIVER = 20,
CUTENSOR_STATUS_IO_ERROR = 21,
}Expand description
cuTENSOR status type returns
The type is used for function status returns. All cuTENSOR library functions return their status, which can have the following values.
Variants
CUTENSOR_STATUS_SUCCESS = 0
The operation completed successfully.
CUTENSOR_STATUS_NOT_INITIALIZED = 1
The opaque data structure was not initialized.
CUTENSOR_STATUS_ALLOC_FAILED = 3
Resource allocation failed inside the cuTENSOR library.
CUTENSOR_STATUS_INVALID_VALUE = 7
An unsupported value or parameter was passed to the function (indicates an user error).
CUTENSOR_STATUS_ARCH_MISMATCH = 8
Indicates that the device is either not ready, or the target architecture is not supported.
CUTENSOR_STATUS_MAPPING_ERROR = 11
An access to GPU memory space failed, which is usually caused by a failure to bind a texture.
CUTENSOR_STATUS_EXECUTION_FAILED = 13
The GPU program failed to execute. This is often caused by a launch failure of the kernel on the GPU, which can be caused by multiple reasons.
CUTENSOR_STATUS_INTERNAL_ERROR = 14
An internal cuTENSOR error has occurred.
CUTENSOR_STATUS_NOT_SUPPORTED = 15
The requested operation is not supported.
CUTENSOR_STATUS_LICENSE_ERROR = 16
The functionality requested requires some license and an error was detected when trying to check the current licensing.
CUTENSOR_STATUS_CUBLAS_ERROR = 17
A call to CUBLAS did not succeed.
CUTENSOR_STATUS_CUDA_ERROR = 18
Some unknown CUDA error has occurred.
CUTENSOR_STATUS_INSUFFICIENT_WORKSPACE = 19
The provided workspace was insufficient.
CUTENSOR_STATUS_INSUFFICIENT_DRIVER = 20
Indicates that the driver version is insufficient.
CUTENSOR_STATUS_IO_ERROR = 21
Indicates an error related to file I/O.