#[repr(u32)]pub enum cutensorWorksizePreference_t {
CUTENSOR_WORKSPACE_MIN = 1,
CUTENSOR_WORKSPACE_DEFAULT = 2,
CUTENSOR_WORKSPACE_MAX = 3,
}Expand description
This enum gives users finer control over the suggested workspace.
This enum gives users finer control over the amount of workspace that is suggested by cutensorEstimateWorkspaceSize.
Variants
CUTENSOR_WORKSPACE_MIN = 1
Least memory requirement; at least one algorithm will be available.
CUTENSOR_WORKSPACE_DEFAULT = 2
Aims to attain high performance while also reducing the workspace requirement.
CUTENSOR_WORKSPACE_MAX = 3
Highest memory requirement; all algorithms will be available (choose this option if memory footprint is not a concern).