pub unsafe extern "C" fn cutensorCreate(
handle: *mut cutensorHandle_t,
) -> cutensorStatus_tExpand description
Initializes the cuTENSOR library and allocates the memory for the library context.
The device associated with a particular cuTENSOR handle is assumed to remain unchanged after the cutensorCreate call. In order for the cuTENSOR library to use a different device, the application must set the new device to be used by calling cudaSetDevice and then create another cuTENSOR handle, which will be associated with the new device, by calling cutensorCreate.
Moreover, each handle by default has a plan cache that can store the least recently used cutensorPlan_t; its default capacity is 64, but it can be changed via cutensorHandleResizePlanCache if this is too little storage space. See the Plan Cache Guide for more information.
The user is responsible for calling cutensorDestroy to free the resources associated with the handle.
Remark
blocking, no reentrant, and thread-safe.