pub unsafe extern "C" fn cutensorDestroy(
handle: cutensorHandle_t,
) -> cutensorStatus_tExpand description
Frees all resources related to the provided library handle.
Remark
blocking, no reentrant, and thread-safe.
pub unsafe extern "C" fn cutensorDestroy(
handle: cutensorHandle_t,
) -> cutensorStatus_tFrees all resources related to the provided library handle.
Remark
blocking, no reentrant, and thread-safe.