cutensorHandleReadPlanCacheFromFile

Function cutensorHandleReadPlanCacheFromFile 

pub unsafe extern "C" fn cutensorHandleReadPlanCacheFromFile(
    handle: cutensorHandle_t,
    filename: *const c_char,
    numCachelinesRead: *mut u32,
) -> cutensorStatus_t
Reads a Plan-Cache from file and overwrites the cachelines of the provided handle.

A cache is only valid for the same cuTENSOR version and CUDA version; moreover, the GPU architecture (incl. multiprocessor count) must match, otherwise cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE will be returned.

Remark

non-blocking, no reentrant, and thread-safe.

Parameters

Return value