pub unsafe extern "C" fn cutensorLoggerOpenFile(
logFile: *const c_char,
) -> cutensorStatus_tExpand description
This function opens a logging output file in the given path.
pub unsafe extern "C" fn cutensorLoggerOpenFile(
logFile: *const c_char,
) -> cutensorStatus_tThis function opens a logging output file in the given path.