pub unsafe extern "C" fn cutensorLoggerSetMask(
mask: i32,
) -> cutensorStatus_tExpand description
This function sets the value of the log mask.
pub unsafe extern "C" fn cutensorLoggerSetMask(
mask: i32,
) -> cutensorStatus_tThis function sets the value of the log mask.