pub unsafe extern "C" fn cutensorMgCreateContractionFind(
handle: cutensorMgHandle_t,
find: *mut cutensorMgContractionFind_t,
algo: cutensorMgAlgo_t,
) -> cutensorStatus_tExpand description
Create a contraction find.
The contraction find contains all the algorithmic options to execute a tensor contraction. For now, its only parameter is an algorithm, which currently only has one default value. It may gain additional options in the future.
Remark
non-blocking, no reentrant, and thread-safe.
Parameters
handle: The library handle.find: The resulting find.algo: The desired algorithm.
Return value
cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE: Some input parameters were invalid.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully.