cutensorMgDestroy

Function cutensorMgDestroy 

pub unsafe extern "C" fn cutensorMgDestroy(
    handle: cutensorMgHandle_t,
) -> cutensorStatus_t
Destroy a library handle.

All outstanding operations must be completed before calling this function. Frees all associated resources. Any descriptors or plans created with the handle become invalid and may only be destructed.

Remark

blocking, no reentrant, and thread-safe.

Return value