cutensorMpDestroy

Function cutensorMpDestroy 

pub unsafe extern "C" fn cutensorMpDestroy(
    handle: cutensorMpHandle_t,
) -> cutensorStatus_t
Frees all resources associated with the provided cutensorMp handle.

This function deallocates all memory and resources associated with a cutensorMp handle that was previously created by cutensorMpCreate. After calling this function, the handle becomes invalid and should not be used in subsequent cutensorMp operations.

Remark

blocking, no reentrant, and thread-safe.