cutensorMpDestroyOperationDescriptor

Function cutensorMpDestroyOperationDescriptor 

pub unsafe extern "C" fn cutensorMpDestroyOperationDescriptor(
    desc: cutensorMpOperationDescriptor_t,
) -> cutensorStatus_t
Frees all resources related to the provided distributed contraction descriptor.

This function deallocates all memory and resources associated with a cutensorMp operation descriptor that was previously created by cutensorMpCreateContraction. After calling this function, the descriptor becomes invalid and should not be used in subsequent cutensorMp operations.

Remark

blocking, no reentrant, and thread-safe.