cutensorPlanPreferenceSetAttribute

Function cutensorPlanPreferenceSetAttribute 

pub unsafe extern "C" fn cutensorPlanPreferenceSetAttribute(
    handle: cutensorHandle_t,
    pref: cutensorPlanPreference_t,
    attr: cutensorPlanPreferenceAttribute_t,
    buf: *const c_void,
    sizeInBytes: size_t,
) -> cutensorStatus_t
Set attribute of a cutensorPlanPreference_t object.

Parameters

  • handle: Opaque handle holding cuTENSOR’s library context.
  • pref: This opaque struct restricts the search space of viable candidates.
  • attr: Specifies the attribute that will be set.
  • buf: This buffer (of size sizeInBytes) determines the value to which attr will be set.
  • sizeInBytes: Size of buf (in bytes); see cutensorPlanPreferenceAttribute_t for the exact size.

Return value