cutensorReadKernelCacheFromFile

Function cutensorReadKernelCacheFromFile 

pub unsafe extern "C" fn cutensorReadKernelCacheFromFile(
    handle: cutensorHandle_t,
    filename: *const c_char,
) -> cutensorStatus_t
Reads a kernel cache from file and adds all non-existing JIT compiled kernels to the kernel cache.

A cache is only valid for the same cuTENSOR version and CUDA version; moreover, the GPU architecture (incl. multiprocessor count) must match, otherwise cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE will be returned.

Remark

non-blocking, no reentrant, and thread-safe.

Parameters

  • handle: Opaque handle holding cuTENSOR’s library context.
  • filename: Specifies the filename (including the absolute path) to the file that holds all the cache information that have previously been written by cutensorWriteKernelCacheToFile.

Return value