pub unsafe extern "C" fn cutensorWriteKernelCacheToFile(
handle: cutensorHandle_t,
filename: *const c_char,
) -> cutensorStatus_tExpand description
Writes the —per library— kernel cache to file.
Writes the just-in-time compiled kernels to the provided file (those kernels belong to the library—not to the handle).
Remark
non-blocking, no reentrant, and thread-safe.
Parameters
handle: Opaque handle holding cuTENSOR’s library context.filename: Specifies the filename (including the absolute path) to the file that should hold all the cache information. Warning: an existing file will be overwritten.
Return value
cutensorStatus_t::CUTENSOR_STATUS_IO_ERROR: if the file cannot be written to.cutensorStatus_t::CUTENSOR_STATUS_NOT_INITIALIZED: if the handle is not initialized.cutensorStatus_t::CUTENSOR_STATUS_NOT_SUPPORTED: if the function is not available for the operating system, CUDA Toolkit, or compute capability of the device.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully or there were no kernels in the cache.