Crate singe_cutensor_sys

Crate singe_cutensor_sys 

Structs

CUstream_st
_IO_FILE
_IO_codecvt
_IO_marker
_IO_wide_data
__BindgenBitfieldUnit
cutensorBlockSparseTensorDescriptor
cutensorComputeDescriptor
cutensorHandle
cutensorOperationDescriptor
cutensorPlan
cutensorPlanPreference
cutensorTensorDescriptor

Enums

cudaDataType_t
cutensorAlgo_t
Allows users to specify the algorithm to be used for performing the desired tensor operation.
cutensorAutotuneMode_t
This enum determines the mode w.r.t. cuTENSOR’s auto-tuning capability.
cutensorCacheMode_t
This enum defines what is considered a cache hit.
cutensorDataType_t
cutensorJitMode_t
This enum determines the mode w.r.t. cuTENSOR’s just-in-time compilation capability.
cutensorOperationDescriptorAttribute_t
This enum lists all attributes of a cutensorOperationDescriptor_t that can be modified (see cutensorOperationDescriptorSetAttribute and cutensorOperationDescriptorGetAttribute).
cutensorOperator_t
This enum captures all unary and binary element-wise operations supported by the cuTENSOR library.
cutensorPlanAttribute_t
This enum lists all attributes of a cutensorPlan_t object that can be retrieved via cutensorPlanGetAttribute.
cutensorPlanPreferenceAttribute_t
This enum lists all attributes of a cutensorPlanPreference_t object that can be modified.
cutensorStatus_t
cuTENSOR status type returns
cutensorWorksizePreference_t
This enum gives users finer control over the suggested workspace.

Constants

CUTENSOR_MAJOR
CUTENSOR_MINOR
CUTENSOR_PATCH
CUTENSOR_VERSION

Statics

CUTENSOR_COMPUTE_DESC_3XTF32
CUTENSOR_COMPUTE_DESC_4X16F
CUTENSOR_COMPUTE_DESC_8XINT8
CUTENSOR_COMPUTE_DESC_9X16BF
CUTENSOR_COMPUTE_DESC_16BF
CUTENSOR_COMPUTE_DESC_16F
CUTENSOR_COMPUTE_DESC_32F
CUTENSOR_COMPUTE_DESC_64F
CUTENSOR_COMPUTE_DESC_TF32
CUTENSOR_C_4I
CUTENSOR_C_4U
CUTENSOR_C_8I
CUTENSOR_C_8U
CUTENSOR_C_16BF
CUTENSOR_C_16F
CUTENSOR_C_16I
CUTENSOR_C_16U
CUTENSOR_C_32F
CUTENSOR_C_32I
CUTENSOR_C_32U
CUTENSOR_C_64F
CUTENSOR_C_64I
CUTENSOR_C_64U
CUTENSOR_R_4I
CUTENSOR_R_4U
CUTENSOR_R_8I
CUTENSOR_R_8U
CUTENSOR_R_16BF
CUTENSOR_R_16F
CUTENSOR_R_16I
CUTENSOR_R_16U
CUTENSOR_R_32F
CUTENSOR_R_32I
CUTENSOR_R_32U
CUTENSOR_R_64F
CUTENSOR_R_64I
CUTENSOR_R_64U

Functions

cutensorBlockSparseContract
This routine computes the block-sparse tensor contraction $D = alpha \* A \* B + beta \* C$.
cutensorContract
This routine computes the tensor contraction $D = alpha \* A \* B + beta \* C$.
cutensorContractTrinary
This routine computes the tensor contraction $E = alpha \* A \* B \* C + beta \* D$.
cutensorCreate
Initializes the cuTENSOR library and allocates the memory for the library context.
cutensorCreateBlockSparseContraction
This function allocates a cutensorOperationDescriptor_t object that encodes a block-sparse tensor contraction of the form $D = \alpha \mathcal{A} \mathcal{B} + \beta \mathcal{C}$.
cutensorCreateBlockSparseTensorDescriptor
Create a block-sparse tensor descriptor.
cutensorCreateContraction
This function allocates a cutensorOperationDescriptor_t object that encodes a tensor contraction of the form $D = \alpha \mathcal{A} \mathcal{B} + \beta \mathcal{C}$.
cutensorCreateContractionTrinary
This function allocates a cutensorOperationDescriptor_t object that encodes a tensor contraction of the form $\mathcal{E} = \alpha \mathcal{A} \mathcal{B} \mathcal{C} + \beta \mathcal{D}$.
cutensorCreateElementwiseBinary
This function creates an operation descriptor for an elementwise binary operation.
cutensorCreateElementwiseTrinary
This function creates an operation descriptor that encodes an elementwise trinary operation.
cutensorCreatePermutation
This function creates an operation descriptor for a tensor permutation.
cutensorCreatePlan
This function allocates a cutensorPlan_t object, selects an appropriate kernel for a given operation (encoded by desc) and prepares a plan that encodes the execution.
cutensorCreatePlanPreference
Allocates the cutensorPlanPreference_t, enabling users to limit the applicable kernels for a given plan/operation.
cutensorCreateReduction
Creates a cutensorOperatorDescriptor_t object that encodes a tensor reduction of the form $D = alpha \* opReduce(opA(A)) + beta \* opC(C)$.
cutensorCreateTensorDescriptor
Creates a tensor descriptor.
cutensorDestroy
Frees all resources related to the provided library handle.
cutensorDestroyBlockSparseTensorDescriptor
Frees all resources related to the provided block-sparse tensor descriptor.
cutensorDestroyOperationDescriptor
Frees all resources related to the provided descriptor.
cutensorDestroyPlan
Frees all resources related to the provided plan.
cutensorDestroyPlanPreference
Frees all resources related to the provided preference.
cutensorDestroyTensorDescriptor
Frees all resources related to the provided tensor descriptor.
cutensorElementwiseBinaryExecute
Performs an element-wise tensor operation for two input tensors (see cutensorCreateElementwiseBinary)
cutensorElementwiseTrinaryExecute
Performs an element-wise tensor operation for three input tensors (see cutensorCreateElementwiseTrinary)
cutensorEstimateWorkspaceSize
Determines the required workspaceSize for the given operation encoded by desc.
cutensorGetCudartVersion
Returns version number of the CUDA runtime that cuTENSOR was compiled against.
cutensorGetErrorString
Returns the description string for an error code.
cutensorGetVersion
Returns Version number of the CUTENSOR library.
cutensorHandleReadPlanCacheFromFile
Reads a Plan-Cache from file and overwrites the cachelines of the provided handle.
cutensorHandleResizePlanCache
Resizes the plan cache.
cutensorHandleWritePlanCacheToFile
Writes the Plan-Cache (that belongs to the provided handle) to file.
cutensorLoggerForceDisable
This function disables logging for the entire run.
cutensorLoggerOpenFile
This function opens a logging output file in the given path.
cutensorLoggerSetCallback
This function sets the logging callback routine.
cutensorLoggerSetFile
This function sets the logging output file.
cutensorLoggerSetLevel
This function sets the value of the logging level.
cutensorLoggerSetMask
This function sets the value of the log mask.
cutensorOperationDescriptorGetAttribute
This function retrieves an attribute of the provided cutensorOperationDescriptor_t object (see cutensorOperationDescriptorAttribute_t).
cutensorOperationDescriptorSetAttribute
Set attribute of a cutensorOperationDescriptor_t object.
cutensorPermute
Performs the tensor permutation that is encoded by plan (see cutensorCreatePermutation).
cutensorPlanGetAttribute
Retrieves information about an already-created plan (see cutensorPlanAttribute_t)
cutensorPlanPreferenceGetAttribute
Get attribute of a cutensorPlanPreference_t object.
cutensorPlanPreferenceSetAttribute
Set attribute of a cutensorPlanPreference_t object.
cutensorReadKernelCacheFromFile
Reads a kernel cache from file and adds all non-existing JIT compiled kernels to the kernel cache.
cutensorReduce
Performs the tensor reduction that is encoded by plan (see cutensorCreateReduction).
cutensorWriteKernelCacheToFile
Writes the —per library— kernel cache to file.

Type Aliases

FILE
_IO_lock_t
__off64_t
__off_t
__uint64_t
cutensorBlockSparseTensorDescriptor_t
Opaque structure representing a block-sparse tensor descriptor.
cutensorComputeDescriptor_t
Opaque structure representing a compute descriptor.
cutensorHandle_t
Opaque structure holding cuTENSOR’s library context.
cutensorLoggerCallback_t
A function pointer type for logging.
cutensorOperationDescriptor_t
Opaque structure representing any type of problem descriptor (e.g., contraction, reduction, elementwise).
cutensorPlanPreference_t
Opaque structure that narrows down the space of applicable algorithms/variants/kernels.
cutensorPlan_t
Opaque structure representing a plan (e.g, contraction, reduction, elementwise).
cutensorTensorDescriptor_t
Opaque structure representing a tensor descriptor.
size_t