cutensorHandleResizePlanCache

Function cutensorHandleResizePlanCache 

pub unsafe extern "C" fn cutensorHandleResizePlanCache(
    handle: cutensorHandle_t,
    numEntries: u32,
) -> cutensorStatus_t
Resizes the plan cache.

This function changes the number of plans that can be stored in the plan cache of the handle.

Resizing invalidates the cache.

While this function is not thread-safe, the resulting cache can be shared across different threads in a thread-safe manner.

Remark

non-blocking, no reentrant, and not thread-safe.

Parameters

  • handle: Opaque handle holding cuTENSOR’s library context. The cache will be attached to the handle.
  • numEntries: Number of entries the cache will support.

Return value