pub unsafe extern "C" fn cutensorMgCreateCopyDescriptor(
handle: cutensorMgHandle_t,
desc: *mut cutensorMgCopyDescriptor_t,
descDst: cutensorMgTensorDescriptor_t,
modesDst: *const i32,
descSrc: cutensorMgTensorDescriptor_t,
modesSrc: *const i32,
) -> cutensorStatus_tExpand description
Create a copy descriptor.
A copy descriptor encodes the source and the destination for a copy operation. The copy operation supports tensors on host, single, or multiple devices. It also supports layout changes and mode permutations. The only restriction is that the extents of the corresponding modes (in the input and output tensors) must match.
Remark
non-blocking, no reentrant, and thread-safe.
Parameters
handle: The library handle.desc: The resulting copy descriptor.descDst: The destination tensor descriptor.modesDst: The destination tensor modes.descSrc: The source tensor descriptor.modesSrc: The source tensor modes.
Return value
cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE: Some input parameters were invalid.cutensorStatus_t::CUTENSOR_STATUS_NOT_SUPPORTED: This tensor layout or precision combination is not supported.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully.