pub unsafe extern "C" fn cutensorMgCreateCopyPlan(
handle: cutensorMgHandle_t,
plan: *mut cutensorMgCopyPlan_t,
desc: cutensorMgCopyDescriptor_t,
deviceWorkspaceSize: *const i64,
hostWorkspaceSize: i64,
) -> cutensorStatus_tExpand description
Create a copy plan.
A copy plan implements the copy operation expressed through the copy descriptor. It contains all the information needed to execute a copy operation. Planning may fail if insufficient workspace is provided.
Remark
non-blocking, no reentrant, and thread-safe.
Parameters
handle: The library handle.plan: The resulting copy plan.desc: The copy descriptor.deviceWorkspaceSize: The amount of workspace that will be provided, for each device in the handle.hostWorkspaceSize: The amount of pinned host workspace that will be provided.
Return value
cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE: Some input parameters were invalid.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully.