pub unsafe extern "C" fn cutensorMgDestroy(
handle: cutensorMgHandle_t,
) -> cutensorStatus_tExpand description
Destroy a library handle.
All outstanding operations must be completed before calling this function. Frees all associated resources. Any descriptors or plans created with the handle become invalid and may only be destructed.
Remark
blocking, no reentrant, and thread-safe.
Return value
cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE: Some input parameters were invalid.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully.