pub unsafe extern "C" fn cutensorMpDestroyPlan(
plan: cutensorMpPlan_t,
) -> cutensorStatus_tExpand description
Frees all resources related to the provided distributed contraction plan.
This function deallocates all memory and resources associated with a cutensorMp execution plan that was previously created by cutensorMpCreatePlan. After calling this function, the plan becomes invalid and should not be used in subsequent cutensorMp operations.
Remark
blocking, no reentrant, and thread-safe.