pub unsafe extern "C" fn cutensorMpDestroyPlanPreference(
pref: cutensorMpPlanPreference_t,
) -> cutensorStatus_tExpand description
Frees all resources related to the provided plan preference object.
This function deallocates all memory and resources associated with a cutensorMp plan preference object that was previously created by cutensorMpCreatePlanPreference. After calling this function, the preference object becomes invalid and should not be used in subsequent cutensorMp operations.
Remark
blocking, no reentrant, and thread-safe.