pub unsafe extern "C" fn cutensorMpDestroyTensorDescriptor(
desc: cutensorMpTensorDescriptor_t,
) -> cutensorStatus_tExpand description
Frees all resources related to the provided distributed tensor descriptor.
This function deallocates all memory and resources associated with a cutensorMp tensor descriptor that was previously created by cutensorMpCreateTensorDescriptor. After calling this function, the descriptor becomes invalid and should not be used in subsequent cutensorMp operations.
Remark
blocking, no reentrant, and thread-safe.