pub unsafe extern "C" fn cutensorOperationDescriptorGetAttribute(
handle: cutensorHandle_t,
desc: cutensorOperationDescriptor_t,
attr: cutensorOperationDescriptorAttribute_t,
buf: *mut c_void,
sizeInBytes: size_t,
) -> cutensorStatus_tExpand description
This function retrieves an attribute of the provided cutensorOperationDescriptor_t object (see cutensorOperationDescriptorAttribute_t).
Block-sparse contraction descriptors only support the attributes cutensorOperationDescriptorAttribute_t::CUTENSOR_OPERATION_DESCRIPTOR_SCALAR_TYPE and cutensorOperationDescriptorAttribute_t::CUTENSOR_OPERATION_DESCRIPTOR_MOVED_BYTES.
Parameters
handle: Opaque handle holding cuTENSOR’s library context.desc: The cutensorOperationDescriptor_t object whos attribute is queried.attr: Specifies the attribute that will be retrieved.buf: This buffer (of size sizeInBytes) will hold the requested attribute of the provided cutensorOperationDescriptor_t object.sizeInBytes: Size of buf (in bytes); see cutensorOperationDescriptorAttribute_t for the exact size.
Return value
cutensorStatus_t::CUTENSOR_STATUS_INVALID_VALUE: if some input data is invalid (this typically indicates an user error).cutensorStatus_t::CUTENSOR_STATUS_NOT_INITIALIZED: if the handle is not initialized.cutensorStatus_t::CUTENSOR_STATUS_SUCCESS: The operation completed successfully.